@@ -46,6 +46,14 @@ class TornadoOctopus(object):
             logging.debug('Auto starting...')
             self.start()
 
+    @property
+    def queue_size(self):
+        return len(self.url_queue)
+
+    @property
+    def is_empty(self):
+        return self.queue_size == 0
+
     def start(self):
         logging.debug('Creating IOLoop and http_client.')
         self.ioloop = IOLoop()
@@ -86,6 +94,15 @@ class TornadoOctopus(object):
 
     def fetch(self, url, handler, method, **kw):
         self.running_urls += 1
+
+        if self.cache:
+            response = self.response_cache.get(url)
+
+            if response is not None:
+                logging.debug('Cache hit on %s.' % url)
+                handler(url, response)
+                return
+
         logging.info('Fetching %s...' % url)
 
         request = HTTPRequest(
